@@ -123,7 +123,7 @@ impl Encode for Vec<u8> {
 }
 
 impl<T: Encode, const N: usize> Encode for [T; N] {
-    fn into_cbor_value(self) -> Value {
+    default fn into_cbor_value(self) -> Value {
         Value::Array(
             IntoIterator::into_iter(self)
                 .map(Encode::into_cbor_value)
@@ -132,6 +132,12 @@ impl<T: Encode, const N: usize> Encode for [T; N] {
     }
 }
 
+impl<const N: usize> Encode for [u8; N] {
+    fn into_cbor_value(self) -> Value {
+        Value::ByteString(self.into())
+    }
+}
+
 impl<T: Encode> Encode for Option<T> {
     fn into_cbor_value(self) -> Value {
         match self {
